import xapian
import threading

from PyQt4.QtCore import (
    QAbstractListModel, QModelIndex, pyqtProperty, pyqtSignal, pyqtSlot)

from totallywired.utils.lastfm import get_similar_tracks
from totallywired.utils.db import get_qterm, qterm_in_db


#~ class _Facet(object):
#~ 
    #~ """ Fake facet object """
#~ 
    #~ def __init__(self, term, termfreq):
        #~ self.term = term
        #~ self.termfreq = termfreq
        #~ return


class SimilarTracksFetcher(threading.Thread):

    def __init__(self, uri, db, artist, track, callback):
        threading.Thread.__init__(self)
        self.daemon = True
        self.db = db
        self.uri = uri
        self.artist = artist
        self.track = track
        self.callback = callback
        return

    def run(self):
        if callable(self.callback):
            # get similar tracks from lastfm
            similar = get_similar_tracks(artist=self.artist, track=self.track)

            # some xapian stuff so we can query db and know if we have
            # any of the 'similartracks' available within our database
            enq = xapian.Enquire(self.db)
            parser = xapian.QueryParser()
            parser.set_default_op(xapian.Query.OP_AND)
            parser.set_database(self.db)
            # preform the db checks, can't really use postlist here 
            # unfortunately...
            
            for s in similar:
                q = parser.parse_query(
                    "%s %s" % (s.artist, s.name),
                    xapian.QueryParser.FLAG_PARTIAL)
                enq.set_query(q)
                # attach indb and docid attrs to each similar item
                mset = enq.get_mset(0, 1)
                s.indb = len(mset) == 1
                if s.indb:
                    s.docid = mset[0].docid
                else:
                    s.docid = -1

            # run callback
            self.callback(self.track, similar)
        return


class SimilarTracksModel(QAbstractListModel):

    ROLE_ALBUM_ART = "_art"
    ROLE_TRACK_NAME = "_track"
    ROLE_ARTIST = "_artist"
    ROLE_TRACK_INDB = "_indb"

    COLUMNS = (
        ROLE_ALBUM_ART,
        ROLE_TRACK_NAME,
        ROLE_ARTIST,
        ROLE_TRACK_INDB)

    ROLES = dict(enumerate(COLUMNS))

    similarTracksReady = pyqtSignal()

    def __init__(self):
        QAbstractListModel.__init__(self)
        self.setRoleNames(SimilarTracksModel.ROLES)
        self._count = 0
        self._values = []
        self.similarTracksReady.connect(self._update_similar)
        return

    def clear(self):
        self.beginResetModel()
        self._count = 0
        self._values = []
        self.endResetModel()
        return

    def _update_similar(self):
        self.beginInsertRows(QModelIndex(), 0, self._count-1)
        self.endInsertRows()
        return

    def set_tracks(self, track, similar):
        self.clear()
        if similar:
            self._values = similar
            self._count = len(similar)
        self.similarTracksReady.emit()
        return

    # QAbstractListModel compliance code
    def rowCount(self, parent=QModelIndex()):
        return self._count

    def data(self, index, role, roles=ROLES):
        if not index.isValid():
            return None

        rolev = roles[role]
        s = self._values[index.row()]

        if rolev == self.ROLE_ARTIST:
            return s.artist.decode("utf-8", "ignore")
        elif rolev == self.ROLE_TRACK_NAME:
            return s.name.decode("utf-8", "ignore")
        elif rolev == self.ROLE_ALBUM_ART:
            return s.image
        elif rolev == self.ROLE_TRACK_INDB:
            return s.indb
        return None

    @pyqtSlot(int)
    def enqueue_grid_index(self, i):
        from totallywired.models.queue import get_queue
        q = get_queue()
        if q is not None:
            i = int(i)
            # handle special case where the get_similar_tracks call 
            # has the limit attr set to something less than the n10 cells
            # we display in the similartracks grid.  not currently
            # the case...
            if i >= len(self._values):
                i = i - len(self._values)
            similar_docid = self._values[i].docid
            q.enqueue_docid(similar_docid)
        return

    @pyqtSlot(int)
    def play_grid_index(self, i):
        print("TODO")
        return
