/*
 * Authors:
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1
import QtDesktop 0.1


FocusScope {
    id: button

    property alias label: label.text
    property alias font: label.font
    property alias checked: _button.checked
    property int textVerticalCenterOffset: 0

    property int verticalPadding: 2
    property int horizontalPadding: 4

    implicitWidth: label.paintedWidth + 2 * horizontalPadding
    implicitHeight: label.paintedHeight + 2 * verticalPadding

    property string hint: "normal"
    property alias active: _button.checked
    property alias tooltip: _button.tooltip

    signal clicked

    Item {
        id: bg

        clip: true
        anchors.fill: parent

        Button {
            id: _button

            x: {
                if (hint == "end" || hint == "internal") {
                    return parent.x - 20
                }
                else
                    return parent.x
            }

            y: parent.y

            width: {
                if (hint == "normal")
                    return parent.width
                else if (hint == "start" || hint == "end")
                    return parent.width + 20
                else if (hint == "internal")
                    return parent.width + 40
            }

            height: parent.height

            onClicked: {
                button.clicked()
            }
        }

        Text {
            id: label
            color: activePalette.text
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenter: parent.verticalCenter
            anchors.verticalCenterOffset: button.textVerticalCenterOffset
        }
    }
}
