/*
 * Authors:
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1


FocusScope {
    id: button

    property alias label: label.text
    property alias font: label.font
    property alias radius: bg.radius
    property color baseColor: Qt.rgba(1,1,1,1)
    property real labelLightenFactor: 1.35

    property int verticalPadding: 2
    property int horizontalPadding: 8
    property int textVerticalCenterOffset: 0

    implicitHeight: verticalPadding*2 + label.paintedHeight
    implicitWidth: horizontalPadding*2 + label.paintedWidth

    property alias bg: bg

    signal clicked

    Rectangle {
        id: bg
        anchors.fill: parent
        opacity: button.opacity
        color: area.pressed ? Qt.darker(baseColor, 1.6) : Qt.darker(baseColor, 1.35)
        border.width: 1
        border.color: Qt.darker(baseColor, 1.55)
        clip: true

        Behavior on width { PropertyAnimation {duration: 150} }

        MouseArea {
            id: area
            anchors.fill: parent
            hoverEnabled: true

            onClicked: {
                button.clicked()
            }
        }

        Text {
            id: label

            anchors.verticalCenter: parent.verticalCenter
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.verticalCenterOffset: textVerticalCenterOffset
            anchors.horizontalCenterOffset: 2

            visible: text != ""
            color: (
                area.containsMouse ?
                Qt.lighter(baseColor, (labelLightenFactor + 0.65)) :
                Qt.lighter(baseColor, labelLightenFactor))

            font.pointSize: 9
            font.bold: true
            style: Text.Raised
            styleColor: Qt.darker(baseColor, 2.0)
        }
    }
}
