/*
 * Authors:
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 1.1
import QtDesktop 0.1


Column {
    id: dataCol

    spacing: 6

    TextField {
        id: title
        objectName: "title"

        function get_changes() {
            return text
        }

        anchors.left: parent.left
        anchors.right: parent.right
        placeholderText: "Unknown"
        text: metaExists() ? metadata.title : ""

        Text {
            color: Qt.darker(activePalette.mid, 1.6)
            text: "<small>TRACK NAME</small>"
            style: Text.Raised
            styleColor: Qt.lighter(activePalette.mid, 1.1667)
            font.bold: true
            anchors.verticalCenter: parent.verticalCenter
            anchors.right: parent.right
            anchors.rightMargin: 10
        }
    }

    CommonFieldTextEntry {
        objectName: "ensemble"
        title: "<small>ALBUM ARTIST</small>"
        placeholderText: "Unknown"
        text: metadata != null ? metadata.aartist : ""
    }

    CommonFieldTextEntry {
        objectName: "artist"
        title: "<small>RECORDING ARTIST</small>"
        placeholderText: "Unknown"
        text: metadata != null ? metadata.artist : ""
    }

    CommonFieldTextEntry {
        objectName: "album"
        title: "<small>ALBUM</small>"
        placeholderText: "Unknown"
        text: metadata != null ? metadata.album : ""
    }

    CommonFieldTextEntry {
        objectName: "tags"
        title: "<small>TAGS</small>"
        placeholderText: "No tags"
        text: metadata != null ? metadata.tags : ""
    }

    Row {
        anchors.left: parent.left
        anchors.right: parent.right
        spacing: 6

        TextField {
            id: date
            objectName: "date"

            function get_changes() {
                return text
            }

            width: (parent.width - 6) / 2
            placeholderText: "Unknown"
            text: metaExists() ? metadata.date : ""

            Text {
                color: Qt.darker(activePalette.mid, 1.6)
                text: "<small>RELEASE DATE</small>"
                style: Text.Raised
                styleColor: Qt.lighter(activePalette.mid, 1.1667)
                font.bold: true
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                anchors.rightMargin: 10
            }
        }

        TextField {
            id: trackn
            objectName: "tracknumber"

            function get_changes() {
                return text
            }

            width: (parent.width - 6) / 2
            placeholderText: "No track number"
            text: metaExists() ? metadata.trackn : ""

            Text {
                color: Qt.darker(activePalette.mid, 1.6)
                text: "<small>TRACK NUMBER</small>"
                style: Text.Raised
                styleColor: Qt.lighter(activePalette.mid, 1.1667)
                font.bold: true
                anchors.verticalCenter: parent.verticalCenter
                anchors.right: parent.right
                anchors.rightMargin: 10
            }
        }
    }

    Text {
        text: "Path: %1".arg(metaExists() ? metadata.path : "")
        font.pointSize: 9
        width: parent.width
        color: "#737373"
        elide: Text.ElideMiddle
    }
}
