/*
 * Authors:
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


import QtQuick 1.1


TrackListDelegate {
    id: row

    Row {
        spacing: 3

        anchors.left: parent.left
        anchors.right: parent.right
        anchors.verticalCenter: parent.verticalCenter

        Text {
            // track no.
            id: content
            color: text_color
            text: trackn
            font.pointSize: _pointSize
            width: list.tracknColWidth
            horizontalAlignment: Text.AlignHCenter
            style: Text.Raised
            styleColor: textstyle_color
        }

        Item{
            width: list.titleColWidth
            height: children[0].implicitHeight

            Text {
                // track title
                color: text_color
                width: parent.width - 3
                text: title
                font.pointSize: _pointSize
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: textstyle_color
                font.bold: isCurrentStream

                Row {
                    id: badges
                
                    x: Math.min(parent.paintedWidth + 3, parent.width - width)
                    anchors.verticalCenter: parent.verticalCenter
                    spacing: 2

                    Text {
                        // heart
                        visible: liked == 1
                        anchors.verticalCenter: parent.verticalCenter
                        text: "\u2665"
                        smooth: false
                        color: text_color
                        style: Text.Raised
                        styleColor: textstyle_color
                        font.pixelSize: 9
                    }

                    Text {
                        // scullxbones
                        visible: liked == 2
                        anchors.verticalCenter: parent.verticalCenter
                        anchors.verticalCenterOffset: 1
                        text: "a"
                        font.family: "TotallyWired"
                        smooth: false
                        color: text_color
                        style: Text.Raised
                        styleColor: textstyle_color
                        font.pointSize: 8
                        font.bold: true
                    }

                    Text {
                        visible: enqueued
                        anchors.verticalCenter: parent.verticalCenter
                        text: "\u21E2"
                        smooth: false
                        color: text_color
                        style: Text.Raised
                        styleColor: textstyle_color
                    }
                }
            }
        }

        Item {
            width: list.albumColWidth
            height: children[0].implicitHeight

            Text {
                // album name
                color: text_color
                x: 3
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width - 6
                text: album
                font.pointSize: _pointSize
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: textstyle_color
                font.bold: isCurrentStream
            }
        }

        Item {
            width: list.artistColWidth
            height: children[0].implicitHeight

            Text {
                // artist name
                color: text_color
                anchors.verticalCenter: parent.verticalCenter
                x: 3
                width: parent.width - 7
                font.pointSize: _pointSize
                text: artist
                elide: Text.ElideMiddle
                style: Text.Raised
                styleColor: textstyle_color
                font.bold: isCurrentStream
            }
        }

        Item {
            width: list.durationColWidth
            height: children[0].implicitHeight

            Text {
                // duration
                color: text_color
                anchors.verticalCenter: parent.verticalCenter
                x: 3
                width: parent.width - 7
                font.pointSize: _pointSize
                text: duration
                style: Text.Raised
                styleColor: textstyle_color
            }
        }

        Item {
            width: 200
            height: children[0].implicitHeight

            Text {
                // tags
                color: isCurrentStream | selected ? Qt.lighter(row.color, 1.8) : Qt.darker(row.color, 1.5)
                anchors.verticalCenter: parent.verticalCenter
                x: 3
                font.pointSize: _pointSize
                text: tags
                style: Text.Raised
                styleColor: textstyle_color
                font.bold: isCurrentStream
            }
        }
    }
}
