/*
 * Authors:
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


import QtQuick 1.1


FocusScope {
    id: listview
    objectName: "musicLibraryView"

    function saveState() {
        console.log(objectName, "saving state...")
        Utils.settings_set_int_val(separator1.x, "qml", "mlsep1x")
        Utils.settings_set_int_val(separator2.y, "qml", "mlsep2y")
    }

    property alias listview: list

    AlbumsBanner {
        id: albumBanner
        model: Collection.albums

        anchors.left: list.left
        anchors.right: list.right
        anchors.top: parent.top
        anchors.bottom: separator2.bottom
    }

    TrackList {
        id: list
        objectName: "musicView"

        anchors.top: albumBanner.bottom
        anchors.left: separator1.right
        anchors.right: parent.right
        anchors.bottom: parent.bottom

        model: Collection
        delegate: MusicCollectionListDelegate {}
    }

    ArtistsList {
        id: artists
        height: parent.height
        anchors.left: parent.left
        anchors.right: separator1.left
    }

    VerSeperatorListView {
        id: separator2

        anchors.left: separator1.right
        anchors.right: parent.right

        Component.onCompleted: {
            y = Utils.settings_get_int_val("qml", "mlsep2y", 200)
        }
    }

    HorSeperatorListView {
        id: separator1
        color: Qt.darker("#BFB6AC", 1.275)
        anchors.top: parent.top
        anchors.bottom: parent.bottom

        Component.onCompleted: {
            x = Utils.settings_get_int_val("qml", "mlsep1x", 200)
        }
    }

    Rectangle {
        // no cdda inserted splash

        anchors.fill: parent
        visible: list.count == 0

        TextLabel {
            id: noResults
            text: {
                if (searchentry.text) {
                    if (searchentry.text == "^^")
                        return "You have not 'liked' any tracks yet"
                    return "Sorry, there is nothing that matches your search"
                }
                else {
                    return "No music is currently available for your listening pleasure"
                }
            }

            font.bold: true
            font.pointSize: 12
            anchors.centerIn: parent
        }
    }
}
