/*
 * Authors:
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


import QtQuick 1.1
import QtDesktop 0.1


Item {
    id: editor
    objectName: "editor"

    signal close
    property variant metadata

    function metaExists() {
        return metadata != undefined
    }

    function set_model(model) {
        metadata = model.get_current_metadata()
    }

    Flickable {
        id: scroller

        clip: true
        boundsBehavior: Flickable.StopAtBounds
        contentHeight: similarTracks.y + similarTracks.height + 48

        anchors.fill: parent

        Rectangle {
            id: bg

            color: activePalette.window
            anchors.fill: parent

            Item {
                width: Math.min(800, parent.width)
                height: parent.height - anchors.topMargin

                anchors.top: parent.top
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.topMargin: 36

                Image {
                    id: albumArtFrame

                    anchors.left: parent.left
                    anchors.top: metaEd.top
                    anchors.topMargin: -4

                    source: "../../../data/art/140x140-album-bg.png"

                    Text {
                        anchors.centerIn: parent
                        text: "No Art."
                        font.bold: true
                        color: activePalette.text
                    }

                    Image {
                        id: albumArt

                        asynchronous: true
                        source: metaExists() ? metadata.album_art : ""

                        anchors.top: parent.top
                        anchors.left: parent.left
                        anchors.topMargin: 8
                        anchors.leftMargin: 9

                        width: parent.width - 19
                        height: parent.width - 19

                        onSourceChanged: SequentialAnimation {
                            PropertyAction {
                                target: albumArt
                                property: "opacity"
                                value: 0.3 }

                            NumberAnimation {
                                target: albumArt
                                property: "opacity"
                                to: 1; duration: 300
                                easing.type: Easing.InOutQuad
                            }
                        }
                    }
                }

                MetadataEditor {
                    id: metaEd

                    width: parent.width - albumArtFrame.width - 12
                    anchors.top: parent.top
                    anchors.left: albumArtFrame.right
                    anchors.topMargin: 6
                    anchors.leftMargin: 12
                }

                TextLabel {
                    id: bio

                    anchors.top: metaEd.bottom
                    anchors.topMargin: 28

                    text: metaExists() ? metadata.bio : ""
                    textFormat: Text.RichText
                    wrapMode: Text.Wrap
                    width: parent.width
                    
                    onLinkActivated: Utils.reveal_location(link)
                }

                TracksBanner {
                    id: similarTracks

                    anchors.top: bio.bottom
                    anchors.left: parent.left
                    anchors.right: parent.right
                    anchors.topMargin: 24
                    model: Collection.similartracks
                }
            }
        }
    }

    MetadataControlRibbon {
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right
    }
}
