/*
 * Authors:
 *  Matthew McGowan <matthew.joseph.mcgowan@gmail.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 3.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */


import QtQuick 1.1
import QtDesktop 0.1


Rectangle {
    id: bg

    property alias model: grid.model

    height: 300 + title.paintedHeight + 18
    color: "#EBE4DF"
    radius: 6

    opacity: grid.count > 0 ? 1 : 0
    Behavior on opacity { PropertyAnimation{duration: 250} }

    TextLabel {
        id: title

        text: "Similar tracks"
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.margins: 6
        font.bold: true
    }

    GridView {
        id: grid

        clip: true
        boundsBehavior: Flickable.StopAtBounds

        anchors.top: title.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.topMargin: 6

        interactive: false

        cellWidth: 150
        cellHeight: 150

        delegate: Item {
            property string art: _art
            property string artist: _artist
            property string track: _track
            property bool indb: _indb

            width: 150
            height: 100

            MouseArea {
                anchors.fill: parent

                onClicked: {
                    if (indb)
                        grid.model.enqueue_grid_index(index)
                }
                
                onDoubleClicked: {
                    if (indb)
                        grid.model.play_grid_index(index)
                }
            }

            Rectangle {
                id: cover

                width: 82
                anchors.top: parent.top
                anchors.topMargin: 12
                anchors.bottom: parent.bottom
                anchors.horizontalCenter: parent.horizontalCenter

                border.color: "black"
                border.width: 1
            }

            Image {
                anchors.fill: cover
                anchors.topMargin: 1
                anchors.leftMargin: 1
                fillMode: Image.PreserveAspectCrop
                source: art
                visible: art != ""
                smooth: true
                clip: true

                Bubble {
                    anchors.bottom: parent.bottom
                    anchors.right: parent.right
                    anchors.margins: 3
                    highlightFactor: 2.25
                    baseColor: "#FF3333"

                    font.family: "TotallyWired"
                    text: indb ? "k" : "b"
                }
            }

            TextLabel {
                id: albumName

                width: 135
                text: track
                font.pointSize: 8
                anchors.horizontalCenter: parent.horizontalCenter
                anchors.topMargin: 6
                anchors.top: cover.bottom
                horizontalAlignment: Text.AlignHCenter
                wrapMode: Text.Wrap
                elide: Text.ElideRight
                maximumLineCount: 2
            }

            Text {
                width: 135
                text: artist
                font.pointSize: 8
                font.bold: true
                color: activePalette.mid
                anchors.horizontalCenter: parent.horizontalCenter
                horizontalAlignment: Text.AlignHCenter
                anchors.topMargin: 4
                anchors.top: albumName.bottom
                elide: Text.ElideRight
            }
        }
    }
}
